@@ -9,7 +9,7 @@ import math
 import os
 from concurrent.futures import Future, ProcessPoolExecutor
 from time import sleep
-from typing import Any, Dict, List, Optional, cast
+from typing import Any, Dict, List, Optional, TypedDict, cast
 
 import coloredlogs  # type: ignore[import]
 import requests
@@ -20,12 +20,6 @@ from . import defaults
 from .metadata_manager import MetadataManager
 from .utils import file_utils
 
-try:
-    from typing import TypedDict
-except ImportError:
-    from typing_extensions import TypedDict
-
-
 # Types --------------------------------------------------------------------------------
 
 
@@ -528,7 +522,7 @@ if __name__ == "__main__":
         blacklist=args.blacklist,
         blacklist_file=args.blacklist_file,
         url=args.url,
-        timeout=args.token,
+        timeout=args.timeout,
         retries=args.retries,
         basic_only=args.basic_only,
         patch=args.patch,
